// # simple-statistics
//
// A simple, literate statistics system.

// Linear Regression
export { default as linearRegression } from "./src/linear_regression.js";
export { default as linearRegressionLine } from "./src/linear_regression_line.js";
export { default as standardDeviation } from "./src/standard_deviation.js";
export { default as rSquared } from "./src/r_squared.js";
export { default as mode } from "./src/mode.js";
export { default as modeFast } from "./src/mode_fast.js";
export { default as modeSorted } from "./src/mode_sorted.js";
export { default as min } from "./src/min.js";
export { default as max } from "./src/max.js";
export { default as extent } from "./src/extent.js";
export { default as minSorted } from "./src/min_sorted.js";
export { default as maxSorted } from "./src/max_sorted.js";
export { default as extentSorted } from "./src/extent_sorted.js";
export { default as sum } from "./src/sum.js";
export { default as sumSimple } from "./src/sum_simple.js";
export { default as product } from "./src/product.js";
export { default as quantile } from "./src/quantile.js";
export { default as quantileSorted } from "./src/quantile_sorted.js";
export { default as quantileRank } from "./src/quantile_rank.js";
export { default as quantileRankSorted } from "./src/quantile_rank_sorted.js";
export {
    default as interquartileRange,
    default as iqr
} from "./src/interquartile_range.js";
export {
    default as medianAbsoluteDeviation,
    default as mad
} from "./src/median_absolute_deviation.js";
export { default as chunk } from "./src/chunk.js";
export { default as sampleWithReplacement } from "./src/sample_with_replacement.js";
export { default as shuffle } from "./src/shuffle.js";
export { default as shuffleInPlace } from "./src/shuffle_in_place.js";
export { default as sample } from "./src/sample.js";
export { default as ckmeans } from "./src/ckmeans.js";
export { default as uniqueCountSorted } from "./src/unique_count_sorted.js";
export { default as sumNthPowerDeviations } from "./src/sum_nth_power_deviations.js";
export { default as equalIntervalBreaks } from "./src/equal_interval_breaks.js";

// sample statistics
export { default as sampleCovariance } from "./src/sample_covariance.js";
export { default as sampleCorrelation } from "./src/sample_correlation.js";
export { default as sampleRankCorrelation } from "./src/sample_rank_correlation.js";
export { default as sampleVariance } from "./src/sample_variance.js";
export { default as sampleStandardDeviation } from "./src/sample_standard_deviation.js";
export { default as sampleSkewness } from "./src/sample_skewness.js";
export { default as sampleKurtosis } from "./src/sample_kurtosis.js";

// combinatorics
export { default as permutationsHeap } from "./src/permutations_heap.js";
export { default as combinations } from "./src/combinations.js";
export { default as combinationsReplacement } from "./src/combinations_replacement.js";

// measures of centrality
export { default as addToMean } from "./src/add_to_mean.js";
export { default as combineMeans } from "./src/combine_means.js";
export { default as combineVariances } from "./src/combine_variances.js";
export { default as geometricMean } from "./src/geometric_mean.js";
export { default as logAverage } from "./src/log_average.js";
export { default as harmonicMean } from "./src/harmonic_mean.js";
export { default as average, default as mean } from "./src/mean.js";

export {
    default as averageSimple,
    default as meanSimple
} from "./src/mean_simple.js";

export { default as median } from "./src/median.js";
export { default as medianSorted } from "./src/median_sorted.js";
export { default as subtractFromMean } from "./src/subtract_from_mean.js";

export {
    default as rootMeanSquare,
    default as rms
} from "./src/root_mean_square.js";
export { default as variance } from "./src/variance.js";
export { default as coefficientOfVariation } from "./src/coefficient_of_variation.js";
export { default as tTest } from "./src/t_test.js";
export { default as tTestTwoSample } from "./src/t_test_two_sample.js";
export { default as wilcoxonRankSum } from "./src/wilcoxon_rank_sum.js";
// ss.jenks = require('./src/jenks');

// Classifiers
export {
    default as BayesianClassifier,
    default as bayesian
} from "./src/bayesian_classifier.js";
export {
    default as PerceptronModel,
    default as perceptron
} from "./src/perceptron.js";

// Distribution-related methods
export { default as epsilon } from "./src/epsilon.js"; // We make ε available to the test suite.
export { default as factorial } from "./src/factorial.js";
export { default as gamma } from "./src/gamma.js";
export { default as gammaln } from "./src/gammaln.js";
export { default as bernoulliDistribution } from "./src/bernoulli_distribution.js";
export { default as binomialDistribution } from "./src/binomial_distribution.js";
export { default as poissonDistribution } from "./src/poisson_distribution.js";
export { default as chiSquaredDistributionTable } from "./src/chi_squared_distribution_table.js";
export { default as chiSquaredGoodnessOfFit } from "./src/chi_squared_goodness_of_fit.js";
export {
    default as kernelDensityEstimation,
    default as kde
} from "./src/kernel_density_estimation.js";

// Normal distribution
export { default as zScore } from "./src/z_score.js";
export { default as cumulativeStdNormalProbability } from "./src/cumulative_std_normal_probability.js";
export { default as cumulativeStdLogisticProbability } from "./src/cumulative_std_logistic_probability.js";
export { default as standardNormalTable } from "./src/standard_normal_table.js";
export {
    default as errorFunction,
    default as erf
} from "./src/error_function.js";
export { default as inverseErrorFunction } from "./src/inverse_error_function.js";
export { default as probit } from "./src/probit.js";
export { default as logit } from "./src/logit.js";

// Non-parametric Methods
export { default as permutationTest } from "./src/permutation_test.js";

// Root-finding methods
export { default as bisect } from "./src/bisect.js";

// Clustering methods and metrics
export { default as kMeansCluster } from "./src/k_means_cluster.js";
export { default as silhouette } from "./src/silhouette.js";
export { default as silhouetteMetric } from "./src/silhouette_metric.js";

// Utils
export { default as quickselect } from "./src/quickselect.js";
export { default as sign } from "./src/sign.js";
export { default as numericSort } from "./src/numeric_sort.js";
export { default as relativeError } from "./src/relative_error.js";
export { default as approxEqual } from "./src/approx_equal.js";
